AssetScanner class
Service responsible for scanning rendered project asset directories.
Constructors
- AssetScanner()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scan(
String projectPath) → List< DiscoveredAsset> -
Scans the
assets/directory inprojectPathand returns a list of DiscoveredAssets. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited