AssetsClassGenerator class

Service responsible for generating a type-safe Assets Dart constant class.

Constructors

AssetsClassGenerator()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate({required String projectPath, required List<DiscoveredAsset> assets, String? relativeFilePath}) → String?
Generates the Assets constant class for assets in projectPath at relativeFilePath.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited