PubspecAssetWriter class

Service responsible for declaring assets inside a project's pubspec.yaml.

Constructors

PubspecAssetWriter()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
write(String projectPath, List<DiscoveredAsset> assets) → void
Writes assets to pubspec.yaml in projectPath.

Operators

operator ==(Object other) → bool
The equality operator.
inherited