ArtifactFinder class
Service responsible for locating compiled Flutter build artifacts in the file system.
Constructors
- ArtifactFinder()
-
Creates an ArtifactFinder instance.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
findArtifact(
{required String projectPath, required BuildFormat format}) → Future< String?> -
Searches for a compiled artifact matching
formatwithin the build directory ofprojectPath. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited