BuildFormat enum

Supported compilation artifact output formats for Flutter builds.

Inheritance
Available extensions

Values

appbundle → const BuildFormat

Android App Bundle format (.aab).

apk → const BuildFormat

Android Package format (.apk).

ipa → const BuildFormat

iOS Application Archive format (.ipa).

Properties

extension → String
File extension expected for this artifact format.
no setter
flutterCommand → String
Corresponding command argument for flutter build <command>.
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
validateForPlatform(BuildPlatform platform) → void
Validates that this format is compatible with the specified platform.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

defaultForPlatform(BuildPlatform platform) → BuildFormat
Returns the recommended default BuildFormat for a given platform.
parse(String value) → BuildFormat
Parses a string into a BuildFormat.

Constants

values → const List<BuildFormat>
A constant List of the values in this enum, in order of their declaration.