BuildManager class

Central coordinator for executing Flutter compilation and packaging commands.

Constructors

BuildManager({ProcessRunner runner = const SystemProcessRunner(), ArtifactFinder artifactFinder = const ArtifactFinder(), TerminalOutput? output})
Creates a BuildManager instance.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

executeBuild(BuildContext context) → Future<List<BuildResult>>
Executes compilation according to the parameters specified in context.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited