BuildPlatform enum

Target platforms supported for Flutter build compilation and deployment.

Inheritance
Available extensions

Values

android → const BuildPlatform

Target the Android platform (APK or App Bundle artifacts).

ios → const BuildPlatform

Target the iOS platform (IPA archive artifacts).

all → const BuildPlatform

Target all supported platforms (Android and iOS).

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
Human-readable identifier for the build platform.
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(String value) → BuildPlatform
Parses a string into a BuildPlatform.

Constants

values → const List<BuildPlatform>
A constant List of the values in this enum, in order of their declaration.