ChangelogManager class

Manager for reading, updating, initializing, and inserting release sections into CHANGELOG.md.

Constructors

ChangelogManager({ReleaseNotesGenerator notesGenerator = const ReleaseNotesGenerator()})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateChangelog(String projectPath, ReleaseNotes notes, {bool init = false, bool overwrite = false, bool dryRun = false, String filename = 'CHANGELOG.md'}) → Future<ChangelogResult>
Updates or initializes CHANGELOG.md in projectPath with notes.

Operators

operator ==(Object other) → bool
The equality operator.
inherited