ClassifiedCommit class

Information about a classified commit.

Constructors

ClassifiedCommit({required GitCommit commit, required CommitCategory category, required String cleanDescription, bool isBreaking = false, String? breakingDescription, bool isRevert = false})
const

Properties

breakingDescription → String?
final
category → CommitCategory
final
cleanDescription → String
final
commit → GitCommit
final
hashCode → int
The hash code for this object.
no setterinherited
isBreaking → bool
final
isRevert → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited