CommitClassifier class

Classifier that categorizes Git commits based on Conventional Commits standards and fallbacks.

Constructors

CommitClassifier()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

classify(List<GitCommit> commits) → List<ClassifiedCommit>
Classifies a list of GitCommit objects into structured categories.
classifyCommit(GitCommit commit) → ClassifiedCommit
Classifies a single GitCommit.
groupByCategory(List<ClassifiedCommit> classified) → Map<String, List<ClassifiedCommit>>
Groups classified commits into a map by CommitCategory.displayName.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited