CIConfig class

Configuration options for CI workflow generation and execution.

Constructors

CIConfig({BuildPlatform platform = BuildPlatform.android, bool force = false, bool dryRun = false, bool generateVerifyWorkflow = true, bool generateReleaseWorkflow = true, bool generatePatchWorkflow = true})
const

Properties

dryRun → bool
final
force → bool
final
generatePatchWorkflow → bool
final
generateReleaseWorkflow → bool
final
generateVerifyWorkflow → bool
final
hashCode → int
The hash code for this object.
no setterinherited
platform → BuildPlatform
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited