CIContext class

Data model representing a snapshot of the CI execution context.

Constructors

CIContext({required bool isCi, required bool isGitHubActions, required String providerName, String? repository, String? branch, String? commitSha, String? runNumber, String? workflow, String? eventName, String? actor, Map<String, String> environment = const {}})
const

Properties

actor → String?
final
branch → String?
final
commitSha → String?
final
environment → Map<String, String>
final
eventName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isCi → bool
final
isGitHubActions → bool
final
providerName → String
final
repository → String?
final
runNumber → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workflow → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited