CIDoctor class
Diagnostic health inspector for CI/CD readiness and configuration.
Constructors
- CIDoctor({CIEnvironment? ciEnvironment, FastlaneRunner fastlaneRunner = const FastlaneRunner(), ShorebirdClient shorebirdClient = const ShorebirdClient()})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
inspect(
String projectPath) → Future< CIDoctorReport> -
Run comprehensive CI health inspection on
projectPath. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited