CIDoctorCheck class

Diagnostic report item produced by CIDoctor.

Constructors

CIDoctorCheck({required String category, required String title, required String status, required String details})
const

Properties

category → String
final
details → String
final
hashCode → int
The hash code for this object.
no setterinherited
isOk → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited