CIDoctorReport class

CIDoctor report container.

Constructors

CIDoctorReport({required List<CIDoctorCheck> checks, required bool isHealthy})
const

Properties

checks → List<CIDoctorCheck>
final
hashCode → int
The hash code for this object.
no setterinherited
isHealthy → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited