WorkflowGenerationResult class

Result object describing workflow generation outcomes.

Constructors

WorkflowGenerationResult({required bool success, List<String> createdFiles = const [], List<String> skippedFiles = const [], List<String> executedSteps = const [], Map<String, String> previews = const {}})
const

Properties

createdFiles → List<String>
final
executedSteps → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
previews → Map<String, String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skippedFiles → List<String>
final
success → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited