WorkflowGenerator class
Generator for GitHub Actions workflow configuration files.
Constructors
- WorkflowGenerator()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateWorkflows(
{required String projectPath, required CIConfig config}) → Future< WorkflowGenerationResult> -
Generate CI workflows for the project at
projectPath. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited