CliApp class

Central CLI Application coordinator.

Constructors

CliApp({required TemplateRepository repository, TerminalOutput? output, CliParser? parser, Prompter? prompter, FeatureGenerator? featureGenerator, ReleaseManager? releaseManager})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerCommand(Command command) → void
Register an executable command.
run(List<String> arguments) → Future<int>
Executes the CLI with raw arguments. Returns exit code integer.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited