CliOptions class

Represents parsed global command options.

Constructors

CliOptions({bool showHelp = false, bool showVersion = false, String? commandName, List<String> commandArgs = const []})
const

Properties

commandArgs → List<String>
final
commandName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showHelp → bool
final
showVersion → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited