ConsolePrompter class
Production implementation of Prompter using standard I/O streams.
- Implemented types
Constructors
- ConsolePrompter({StringSink? out, Stdin? stdin})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
askChoice(
String question, List< String> options, {String? defaultValue}) → String -
Prompts to select one choice from
options.override -
askText(
String question, {String? defaultValue}) → String -
Prompts for text input with optional
defaultValue.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited