Prompter class abstract interface

Interface for interactive CLI prompts.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

askChoice(String question, List<String> options, {String? defaultValue}) → String
Prompts to select one choice from options.
askText(String question, {String? defaultValue}) → String
Prompts for text input with optional defaultValue.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited