ReleaseSummaryCommand class

Command to output a comprehensive release summary (text or JSON).

Implemented types

Constructors

ReleaseSummaryCommand(TerminalOutput _output, {ReleaseMetadataManager? metadataManager, ReleaseSummaryGenerator? summaryGenerator, GitClient? gitClient, CommitClassifier? classifier, PatchChangeAnalyzer? patchAnalyzer})

Properties

description → String
A brief description of what the command does.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
name → String
The command invocation name (e.g. 'create', 'templates').
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(List<String> arguments) → Future<int>
Executes the command with the provided arguments. Returns an integer exit code (0 for success).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited