DependencyConfig class
Represents a package dependency declaration in a template configuration.
Constructors
- DependencyConfig({required String name, String? version, bool isDevDependency = false})
-
const
- DependencyConfig.fromYaml(dynamic entry, {bool isDevDependency = false})
-
Parse a dependency entry from YAML (String or Map).
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isDevDependency → bool
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override