FileConfig class

Represents a individual file template definition.

Constructors

FileConfig({required String targetPath, String? templatePath, String? content})
const
FileConfig.fromYaml(dynamic entry)
factory

Properties

content → String?
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetPath → String
final
templatePath → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override