FolderConfig class
Represents a folder or file configuration target in a template.
Constructors
- FolderConfig(String path)
-
const
- FolderConfig.fromYaml(dynamic entry)
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override