TemplateConfig class
Typed configuration model representing a template's metadata and specs.
Constructors
-
TemplateConfig({required String name, required String description, List<
DependencyConfig> dependencies = const [], List<DependencyConfig> devDependencies = const [], List<FolderConfig> folders = const [], List<FileConfig> files = const [], String assetsClassPath = 'lib/core/constants/assets.dart'}) -
const
- TemplateConfig.fromYamlMap(Map yamlMap)
-
Factory constructor to parse YamlMap or Map into a TemplateConfig.
factory
- TemplateConfig.fromYamlString(String yamlString)
-
Parses YAML string content.
factory
Properties
- assetsClassPath → String
-
final
-
dependencies
→ List<
DependencyConfig> -
final
- description → String
-
final
-
devDependencies
→ List<
DependencyConfig> -
final
-
files
→ List<
FileConfig> -
final
-
folders
→ List<
FolderConfig> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited