FastlaneToolValidator class

Validation check for verifying Fastlane tool installation.

Constructors

FastlaneToolValidator({FastlaneRunner runner = const FastlaneRunner()})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(dynamic context) → Future<ValidationCheck>

Operators

operator ==(Object other) → bool
The equality operator.
inherited