validate method

Future<ValidationCheck> validate(
  1. dynamic context
)

Implementation

Future<ValidationCheck> validate(dynamic context) async {
  final isAvailable = await _runner.isFastlaneAvailable();
  if (isAvailable) {
    return ValidationCheck(
      name: name,
      status: CheckStatus.passed,
      message: 'Fastlane tool is installed and available on system PATH.',
    );
  } else {
    return ValidationCheck(
      name: name,
      status: CheckStatus.failed,
      message: 'Fastlane tool is not installed or not found on system PATH. '
          'Please install Fastlane (https://fastlane.tools) before deploying.',
    );
  }
}