TargetEnvironment enum

Supported release channels and target execution environments.

Inheritance
Available extensions

Values

development → const TargetEnvironment
const TargetEnvironment('development', ['dev', 'debug'])
staging → const TargetEnvironment
const TargetEnvironment('staging', ['stg', 'stage', 'beta', 'internal'])
production → const TargetEnvironment
const TargetEnvironment('production', ['prod', 'release', 'live'])

Properties

aliases → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(String raw) → TargetEnvironment
Normalizes and parses an environment string into a TargetEnvironment.

Constants

values → const List<TargetEnvironment>
A constant List of the values in this enum, in order of their declaration.