FlutterCommandException class
Exception thrown when executing external flutter process commands fails.
- Inheritance
-
- Object
- CliException
- FlutterCommandException
Constructors
Properties
-
arguments
→ List<
String> -
final
- executable → String
-
final
- exitCode → int
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderr → String
-
final
- stdout → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited