PackageInstallException class

Exception thrown when installing package dependencies fails.

Inheritance

Constructors

PackageInstallException({required String packageName, required String errorDetails, required List<String> installedBeforeFailure, required bool isDevDependency})

Properties

errorDetails → String
final
exitCode → int
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
installedBeforeFailure → List<String>
final
isDevDependency → bool
final
message → String
finalinherited
packageName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited