TemplateException class
Exception thrown when a template cannot be found, loaded, or parsed.
- Inheritance
-
- Object
- CliException
- TemplateException
- Implementers
Constructors
- TemplateException(String message, {int exitCode = 69})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited