GenerationResult class

Structured summary of complete project scaffolding.

Constructors

GenerationResult({required String projectPath, required Template template, required RenderResult renderResult, required PackageInstallResult installResult, int discoveredAssetsCount = 0, String? assetsClassPath})
const

Properties

assetsClassPath → String?
final
discoveredAssetsCount → int
final
hashCode → int
The hash code for this object.
no setterinherited
installResult → PackageInstallResult
final
projectPath → String
final
renderResult → RenderResult
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
template → Template
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited