GeneratorContext class

Context parameters for project generation.

Constructors

GeneratorContext({required String projectName, required Template template, required String targetDirectory})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
projectName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetDirectory → String
final
template → Template
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited