GitOperationResult class

Result object for Git operations like tag creation.

Constructors

GitOperationResult({required bool success, required String message, String? output, List<String> errors = const []})
const
GitOperationResult.failure(String message, {List<String> errors = const []})
factory
GitOperationResult.success(String message, {String? output})
factory

Properties

errors → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
output → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited