GitCommit class

Model representing a Git commit in the repository log.

Constructors

GitCommit({required String sha, required String shortSha, required String subject, String body = '', required String author, required DateTime timestamp, List<String> changedFiles = const []})
const
GitCommit.fromJson(Map<String, dynamic> json)
factory

Properties

author → String
final
body → String
final
changedFiles → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha → String
final
shortSha → String
final
subject → String
final
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited