GitCommitRange class

Represents a range of Git commits between two references (e.g. v1.8.1 to HEAD).

Constructors

GitCommitRange({String? fromTag, String? fromCommit, required String toCommit, List<GitCommit> commits = const []})
const

Properties

commitCount → int
no setter
commits → List<GitCommit>
final
fromCommit → String?
final
fromTag → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toCommit → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited