HttpResponseData class

Result from an HTTP request execution.

Constructors

HttpResponseData({required int statusCode, required String body})
const

Properties

body → String
final
hashCode → int
The hash code for this object.
no setterinherited
isSuccess → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited