ProviderStatus class

Status summary for a notification provider configuration.

Constructors

ProviderStatus({required String providerName, required bool isConfigured, List<String> issues = const []})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isConfigured → bool
final
issues → List<String>
final
providerName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited