GitHubProvider class
Provider for GitHub CI integration (step summaries & status updates).
- Implemented types
Constructors
- GitHubProvider({NotificationHttpClient client = const NotificationHttpClient()})
-
const
Properties
Methods
-
isConfigured(
Map< String, String> environment) → bool -
Checks if
environmentcontains necessary credentials or configuration for this provider.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
NotificationPayload payload, {required Map< String, String> environment, bool dryRun = false}) → Future<NotificationResult> -
Dispatches
payloadto the destination. Network calls MUST be skipped ifdryRunis true.override -
toString(
) → String -
A string representation of this object.
inherited
-
validateConfig(
Map< String, String> environment) → List<String> -
Validates configuration and returns any configuration issues or missing variables.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited