SlackProvider class

Provider for sending release notifications to Slack webhooks.

Implemented types

Constructors

SlackProvider({NotificationHttpClient client = const NotificationHttpClient()})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Name identifier of the notification provider (e.g. 'slack', 'discord', 'webhook', 'github').
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isConfigured(Map<String, String> environment) → bool
Checks if environment contains necessary credentials or configuration for this provider.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(NotificationPayload payload, {required Map<String, String> environment, bool dryRun = false}) → Future<NotificationResult>
Dispatches payload to the destination. Network calls MUST be skipped if dryRun is true.
override
toString() → String
A string representation of this object.
inherited
validateConfig(Map<String, String> environment) → List<String>
Validates configuration and returns any configuration issues or missing variables.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited