PackageInstallResult class

Result summary model returned by PackageManager.

Constructors

PackageInstallResult({List<String> installedDependencies = const [], List<String> installedDevDependencies = const []})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
installedDependencies → List<String>
final
installedDevDependencies → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited