SystemProcessRunner class

Production implementation of ProcessRunner using Process.run or Process.start.

Implemented types

Constructors

SystemProcessRunner()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(String executable, List<String> arguments, {String? workingDirectory, void onStdout(String line)?, void onStderr(String line)?, Map<String, String>? environment}) → Future<ProcessResult>
Executes executable with arguments in workingDirectory. Optionally streams stdout/stderr lines to onStdout and onStderr.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited