ReleaseNotes class

Model containing structured release notes data.

Constructors

ReleaseNotes({required String version, String? previousVersion, String? tag, String? previousTag, GitCommitRange? commitRange, required Map<String, List<ClassifiedCommit>> categories, List<ClassifiedCommit> breakingChanges = const [], List<GitCommit> commits = const [], DateTime? generatedAt})

Properties

breakingChanges → List<ClassifiedCommit>
final
categories → Map<String, List<ClassifiedCommit>>
final
commitRange → GitCommitRange?
final
commits → List<GitCommit>
final
generatedAt → DateTime
final
hasBreakingChanges → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
previousTag → String?
final
previousVersion → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String?
final
totalCommits → int
no setter
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited