ReleaseNotesGenerator class

Service for building and formatting structured release notes.

Constructors

ReleaseNotesGenerator({CommitClassifier classifier = const CommitClassifier(), GitClient gitClient = const GitClient()})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate({required String projectPath, required String version, String? previousTag, String? currentTag}) → Future<ReleaseNotes>
Generates a ReleaseNotes object for a given projectPath and target version.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(ReleaseNotes notes, ReleaseNotesFormat format) → String
Renders notes into the specified format.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited