ReleaseSummaryGenerator class

Service for generating formatted release summaries.

Constructors

ReleaseSummaryGenerator()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromMetadata(ReleaseMetadata metadata, {int commitCount = 0, bool hasBreakingChanges = false, Map<String, int> categoryCounts = const {}, Map<String, dynamic>? shorebirdPatchDetails}) → ReleaseSummary
Builds a ReleaseSummary from a ReleaseMetadata manifest.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(ReleaseSummary summary, {bool asJson = false}) → String
Formats summary as text or JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited