ReleaseConfig class

Configuration options for release automation.

Constructors

ReleaseConfig({ReleaseType defaultReleaseType = ReleaseType.normal, bool dryRun = false, bool isCi = false, bool allowDirty = false, String? targetPlatform, String? format, bool deploy = false, String? lane, bool createTag = false, String tagPrefix = 'v', String? environmentName, String? flavor, Map<String, String> dartDefines = const {}})
Creates a ReleaseConfig instance.
const

Properties

allowDirty → bool
Whether uncommitted working tree changes are allowed.
final
createTag → bool
Whether to create Git release tag.
final
dartDefines → Map<String, String>
Dart define key-value pairs.
final
defaultReleaseType → ReleaseType
Default release strategy type.
final
deploy → bool
Whether to deploy after build completion.
final
dryRun → bool
Whether execution is simulated in dry-run mode.
final
environmentName → String?
Target environment name.
final
flavor → String?
Target build flavor.
final
format → String?
Target artifact build format.
final
hashCode → int
The hash code for this object.
no setterinherited
isCi → bool
Whether running within a CI pipeline.
final
lane → String?
Fastlane lane name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagPrefix → String
Git release tag prefix.
final
targetPlatform → String?
Target build platform name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited