ReleaseContext class
Context object carrying runtime state and options across the release execution pipeline.
Constructors
-
ReleaseContext({required String projectPath, required ReleaseType type, bool dryRun = false, bool isCi = false, bool allowDirty = false, VersionBumpMode versionBumpMode = VersionBumpMode.none, String? targetPlatform, String? versionName, int? buildNumber, ReleaseConfig config = const ReleaseConfig(), Map<
String, String> environment = const {}}) -
const
Properties
- allowDirty → bool
-
final
- buildNumber → int?
-
final
- config → ReleaseConfig
-
final
-
dartDefines
→ Map<
String, String> -
Map of custom compilation
--dart-definekey-value pairs.no setter - dryRun → bool
-
final
-
environment
→ Map<
String, String> -
final
- environmentName → String?
-
Target environment name associated with the release (optional).
no setter
- flavor → String?
-
Target build flavor associated with the release (optional).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCi → bool
-
final
- projectPath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetPlatform → String?
-
final
- type → ReleaseType
-
final
- versionBumpMode → VersionBumpMode
-
final
- versionName → String?
-
final
Methods
-
copyWith(
{String? projectPath, ReleaseType? type, bool? dryRun, bool? isCi, bool? allowDirty, VersionBumpMode? versionBumpMode, String? targetPlatform, String? versionName, int? buildNumber, ReleaseConfig? config, Map< String, String> ? environment}) → ReleaseContext - Creates a copy of this context with updated properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited