ReleaseLockManager class

Local file-based process lock manager preventing concurrent release execution.

Constructors

ReleaseLockManager({Duration staleTimeout = const Duration(hours: 1)})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

acquireLock(String projectPath, {required String operation, bool dryRun = false}) → Future<bool>
Attempts to acquire local process lock for projectPath.
getLockFilePath(String projectPath) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseLock(String projectPath, {bool dryRun = false}) → Future<void>
Releases the local process lock for projectPath.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited