ReleaseMetadata class
Machine-readable metadata model describing a completed release or patch operation.
Constructors
-
ReleaseMetadata({required String versionName, required String buildNumber, required String releaseMode, required List<
String> platforms, String? tag, String? previousTag, String? commitSha, String? branch, int? commitCount, bool? hasBreakingChanges, Map<String, int> categories = const {}, String? environment, String? flavor, String? timestamp, Map<String, String> artifacts = const {}, String? deploymentStatus}) - Creates a ReleaseMetadata instance.
-
ReleaseMetadata.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
artifacts
→ Map<
String, String> -
Artifact key-path map.
final
- branch → String?
-
Checked-out Git branch name.
final
- buildNumber → String
-
Release build number string.
final
-
categories
→ Map<
String, int> -
Map of commit categories to count.
final
- commitCount → int?
-
Total commit count on branch.
final
- commitSha → String?
-
Commit SHA string.
final
- deploymentStatus → String?
-
Final deployment status string.
final
- environment → String?
-
Target release environment.
final
- flavor → String?
-
Target build flavor.
final
- hasBreakingChanges → bool?
-
Whether commit range has breaking changes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
platforms
→ List<
String> -
Target release platforms.
final
- previousTag → String?
-
Previous Git tag name.
final
- releaseMode → String
-
Execution release mode (
normalorshorebird).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
Associated Git tag name.
final
- timestamp → String
-
ISO 8601 release timestamp.
final
- versionName → String
-
Release version name string.
final
Methods
-
encodeJson(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited