ReleaseMetadataManager class

Manager for writing, loading, and verifying release manifests.

Constructors

ReleaseMetadataManager()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLatestMetadata(String projectPath) → Future<ReleaseMetadata?>
Alias for loadLatestMetadata.
getManifestDirectory(String projectPath) → String
Directory where release manifests are persisted relative to projectPath.
getReleaseHistory(String projectPath) → Future<List<ReleaseMetadata>>
Alias for loadAllMetadata.
loadAllMetadata(String projectPath) → Future<List<ReleaseMetadata>>
Loads all historical release manifests for projectPath ordered by timestamp descending.
loadLatestMetadata(String projectPath) → Future<ReleaseMetadata?>
Loads the most recent release manifest for projectPath.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveMetadata(String projectPath, ReleaseMetadata metadata, {bool dryRun = false}) → Future<String>
Persists metadata as a machine-readable JSON manifest file on disk.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited