ReleaseStatus enum

Status state of a release or patch operation lifecycle.

Inheritance
Available extensions

Values

created → const ReleaseStatus
const ReleaseStatus('created')
validated → const ReleaseStatus
const ReleaseStatus('validated')
versioned → const ReleaseStatus
const ReleaseStatus('versioned')
building → const ReleaseStatus
const ReleaseStatus('building')
built → const ReleaseStatus
const ReleaseStatus('built')
deploying → const ReleaseStatus
const ReleaseStatus('deploying')
deployed → const ReleaseStatus
const ReleaseStatus('deployed')
completed → const ReleaseStatus
const ReleaseStatus('completed')
failed → const ReleaseStatus
const ReleaseStatus('failed')
cancelled → const ReleaseStatus
const ReleaseStatus('cancelled')
shorebirdReleaseStarted → const ReleaseStatus
const ReleaseStatus('shorebird_release_started')
shorebirdReleaseCreated → const ReleaseStatus
const ReleaseStatus('shorebird_release_created')
storeDeploymentStarted → const ReleaseStatus
const ReleaseStatus('store_deployment_started')
storeDeploymentCompleted → const ReleaseStatus
const ReleaseStatus('store_deployment_completed')
patchStarted → const ReleaseStatus
const ReleaseStatus('patch_started')
patchValidated → const ReleaseStatus
const ReleaseStatus('patch_validated')
patchCreated → const ReleaseStatus
const ReleaseStatus('patch_created')
patchCompleted → const ReleaseStatus
const ReleaseStatus('patch_completed')
patchFailed → const ReleaseStatus
const ReleaseStatus('patch_failed')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
key → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(String raw) → ReleaseStatus

Constants

values → const List<ReleaseStatus>
A constant List of the values in this enum, in order of their declaration.