ReleaseType enum
Strongly typed representation of supported release modes.
Values
- normal → const ReleaseType
-
Standard store release (Google Play / Apple App Store).
const ReleaseType('normal', 'Normal Flutter Release') - shorebirdRelease → const ReleaseType
-
Shorebird baseline release creating a new store build.
const ReleaseType('shorebird', 'Shorebird Baseline Release') - shorebirdPatch → const ReleaseType
-
Shorebird patch updating an existing release over the air.
const ReleaseType('patch', 'Shorebird Patch')
Properties
- cliName → String
-
Command-line argument name (e.g. 'normal', 'shorebird').
final
- displayName → String
-
Display title for logs and output.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ReleaseType> - A constant List of the values in this enum, in order of their declaration.