NormalReleaseStrategy class

Strategy executing normal Flutter compilation builds (Android AAB/APK, iOS IPA).

Implemented types

Constructors

NormalReleaseStrategy({BuildManager? buildManager, DeploymentManager? deploymentManager, GitClient? gitClient, ReleaseMetadataManager? metadataManager})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ReleaseType
The release type handled by this strategy.
no setteroverride

Methods

execute(ReleaseContext context) → Future<ReleaseResult>
Executes the release workflow represented by this strategy.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited