GitValidator class

Validates Git repository status and working tree cleanliness.

Implemented types

Constructors

GitValidator({GitClient gitClient = const GitClient()})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(ReleaseContext context) → Future<ValidationCheck>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited