ValidationCheck class

Represents an individual pre-flight check result.

Constructors

ValidationCheck({required String name, required CheckStatus status, required String message, String? details})
const

Properties

details → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isFailed → bool
no setter
isPassed → bool
no setter
isWarning → bool
no setter
message → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → CheckStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited