PatchChangeAnalyzer class

Component analyzing Git repository changes to classify modified files and evaluate OTA patch eligibility.

Constructors

PatchChangeAnalyzer({GitClient gitClient = const GitClient()})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

analyze(String projectPath) → Future<PatchEligibilityResult>
Alias for analyzeWorkingTree.
analyzeFiles(List<String> filePaths) → PatchEligibilityResult
Classifies filePaths into PatchChangeCategory buckets and evaluates eligibility.
analyzeWorkingTree(String projectPath) → Future<PatchEligibilityResult>
Analyzes changed files in projectPath working tree and evaluates patch eligibility.
classifyFile(String filePath) → PatchChangeCategory
Classifies a single file path into a PatchChangeCategory.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited