Template class

Entity representing a project scaffolding template.

Constructors

Template({required String name, required String description, required TemplateConfig config, String? path})
const
Template.fromConfig(TemplateConfig config, {String? path})
factory

Properties

config → TemplateConfig
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
path → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited