TemplateRenderer class

Standalone, framework-agnostic template rendering engine.

Constructors

TemplateRenderer()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render({required Template template, required Map<String, String> variables, required String destinationPath, bool overwriteExisting = false}) → RenderResult
Renders template using variables into destinationPath.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited