TemplateRepository class abstract interface

Contract for retrieving and querying templates.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAvailableTemplates() → List<Template>
Returns all available templates.
getTemplate(String name) → Template
Returns a template by name. Throws TemplateNotFoundException if not found.
hasTemplate(String name) → bool
Returns true if a template with name exists.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited