TokenSubstitutor class abstract final

Utility function for performing {{token}} string substitution.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

substitute(String input, Map<String, String> variables, {bool allowUnresolved = false}) → String
Substitutes all {{token}} occurrences in input using variables.