Validation utilities for flutter_setup.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
validateExistingFlutterProject(
Directory projectDir) → void -
Validates that
projectDirpoints to a valid existing Flutter project directory. Checks thatpubspec.yamlexists and contains aflutter:key. -
validateFlutterProjectName(
String? name) → void -
Validates that
nameis a valid Flutter/Dart package identifier. Throws ValidationException if the name is invalid.