PubspecVersionHandler class

Reads and safely updates the version: property in a project's pubspec.yaml file.

Constructors

PubspecVersionHandler()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readVersion(File pubspecFile) → ProjectVersion
Reads the current ProjectVersion from pubspecFile.
toString() → String
A string representation of this object.
inherited
writeVersion(File pubspecFile, ProjectVersion newVersion) → void
Writes newVersion into pubspecFile preserving all unrelated formatting and comments.

Operators

operator ==(Object other) → bool
The equality operator.
inherited