DiscoveredAsset class
Represents a discovered asset file inside a project's assets/ folder.
Constructors
- DiscoveredAsset({required String relativePath, required String category, required String fileName})
-
Creates a DiscoveredAsset instance.
const
Properties
- category → String
-
Asset category or subfolder name.
final
- fileName → String
-
File basename.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- relativePath → String
-
Relative file path within project.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override