CommitCategory enum
Categories for classified commits.
Values
- features → const CommitCategory
-
const CommitCategory('Features') - bugFixes → const CommitCategory
-
const CommitCategory('Bug Fixes') - performance → const CommitCategory
-
const CommitCategory('Performance') - refactoring → const CommitCategory
-
const CommitCategory('Refactoring') - documentation → const CommitCategory
-
const CommitCategory('Documentation') - buildCi → const CommitCategory
-
const CommitCategory('Build / CI') - tests → const CommitCategory
-
const CommitCategory('Tests') - otherChanges → const CommitCategory
-
const CommitCategory('Other Changes')
Properties
- displayName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CommitCategory> - A constant List of the values in this enum, in order of their declaration.