DeploymentContext class
Context holding parameters for a store deployment operation.
Constructors
-
DeploymentContext({required String projectPath, required BuildPlatform platform, String? artifactPath, String? lane, String? versionName, String? buildNumber, String? flavor, bool dryRun = false, Map<
String, String> environment = const {}}) -
Creates a DeploymentContext instance.
const
Properties
- artifactPath → String?
-
Path to the artifact file to deploy (
.aabor.ipa).final - buildNumber → String?
-
Build number string associated with the release (optional).
final
- dryRun → bool
-
Whether this is a dry-run preview execution.
final
-
environment
→ Map<
String, String> -
Environment variables map passed to Fastlane execution.
final
- flavor → String?
-
Build flavor string associated with the release (optional).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lane → String?
-
Fastlane lane name (e.g., 'internal', 'testflight', 'beta', 'production').
final
- platform → BuildPlatform
-
Target platform for deployment (
android,ios, orall).final - projectPath → String
-
Path to the target project directory.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- versionName → String?
-
Version name string associated with the release (optional).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited