DeploymentManager class
Central coordinator for executing store deployment strategies.
Constructors
-
DeploymentManager({Map<
BuildPlatform, DeploymentStrategy> ? strategies, FastlaneRunner fastlaneRunner = const FastlaneRunner(), dynamic toolValidator, dynamic projectValidator})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deploy(
DeploymentContext context) → Future< List< DeploymentResult> > -
Execute deployment for the specified platform(s) in
context. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validatePrerequisites(
DeploymentContext context) → Future< ValidationCheck> - Validate deployment prerequisites (tool installation and project configuration).
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited