DeploymentResult class
Result object describing the outcome of a store deployment operation.
Constructors
-
DeploymentResult({required bool success, required BuildPlatform platform, required String lane, required String message, String? artifactPath, List<
String> executedSteps = const [], List<String> errors = const [], List<String> warnings = const [], String? commandString, Map<String, dynamic> metadata = const {}}) -
const
-
DeploymentResult.failure({required BuildPlatform platform, required String lane, required String message, String? artifactPath, List<
String> executedSteps = const [], List<String> errors = const [], List<String> warnings = const [], String? commandString, Map<String, dynamic> metadata = const {}}) -
factory
-
DeploymentResult.success({required BuildPlatform platform, required String lane, required String message, String? artifactPath, List<
String> executedSteps = const [], List<String> warnings = const [], String? commandString, Map<String, dynamic> metadata = const {}}) -
factory
Properties
- artifactPath → String?
-
Artifact path deployed.
final
- commandString → String?
-
Command string executed (or dry-run preview).
final
-
errors
→ List<
String> -
Error messages if deployment failed.
final
-
executedSteps
→ List<
String> -
Steps executed during deployment.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lane → String
-
Lane executed by Fastlane.
final
- message → String
-
Status or summary message.
final
-
metadata
→ Map<
String, dynamic> -
Additional metadata.
final
- platform → BuildPlatform
-
Target platform of deployment.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Whether the deployment completed successfully.
final
-
warnings
→ List<
String> -
Warning messages encountered during deployment.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited