DeploymentStrategy class abstract
Base contract for platform-specific deployment strategies.
- Implementers
Constructors
Properties
- defaultLane → String
-
Default Fastlane lane name for this strategy.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- platform → BuildPlatform
-
Target build platform.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deploy(
DeploymentContext context) → Future< DeploymentResult> - Execute deployment using the given context.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited