IosDeploymentStrategy class
Strategy for publishing iOS IPAs (.ipa) to App Store Connect / TestFlight via Fastlane.
- Implemented types
Constructors
- IosDeploymentStrategy({FastlaneRunner fastlaneRunner = const FastlaneRunner(), ArtifactFinder artifactFinder = const ArtifactFinder()})
Properties
- defaultLane → String
-
Default Fastlane lane name for this strategy.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- platform → BuildPlatform
-
Target build platform.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deploy(
DeploymentContext context) → Future< DeploymentResult> -
Execute deployment using the given context.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited