FastlaneRunner class
Runner responsible for invoking Fastlane CLI commands safely.
Constructors
- FastlaneRunner({ProcessRunner processRunner = const SystemProcessRunner()})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
executeLane(
{required String projectPath, required BuildPlatform platform, required String lane, String? artifactPath, bool dryRun = false, Map< String, String> environment = const {}}) → Future<DeploymentResult> - Execute a fastlane deployment lane.
-
isFastlaneAvailable(
) → Future< bool> - Checks if Fastlane CLI is available on system PATH.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited