EnvironmentConfig class
Configuration definition for a target release channel / execution environment.
Constructors
Properties
-
dartDefines
→ Map<
String, String> -
final
- flavor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lane → String?
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shorebirdAppId → String?
-
final
- target → TargetEnvironment
-
Standard enum representation of the environment name.
no setter
Methods
-
copyWith(
{String? name, String? flavor, String? lane, Map< String, String> ? dartDefines, String? shorebirdAppId}) → EnvironmentConfig - Creates a copy of this config with updated properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited