EnvironmentResolver class
Resolves the effective target environment configuration based on CLI options, process environment variables, and project configuration files.
Constructors
- EnvironmentResolver()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
{String? cliEnvironment, String? cliFlavor, Map< String, String> ? cliDartDefines, Map<String, String> envVars = const {}, Map<String, EnvironmentConfig> configEnvironments = const {}}) → EnvironmentConfig - Resolves environment settings given optional CLI arguments, environment variables, and configured environments.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited