CreateProjectRequest class
Value object representing parameters for project creation.
Constructors
- CreateProjectRequest({required String projectName, String templateName = 'default', String description = 'A new Flutter project', bool force = false})
-
const
Properties
- description → String
-
final
- force → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- templateName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited