NotificationHttpClient class
HTTP client abstraction for dispatching notification webhook requests securely.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxRetries → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postJson(
String url, {required Map< String, dynamic> jsonPayload, Map<String, String> headers = const {}, bool dryRun = false}) → Future<HttpResponseData> -
Dispatches an HTTP request to
url. -
sendRequest(
String url, {required String method, required Map< String, String> headers, required String body, bool dryRun = false}) → Future<HttpResponseData> -
Dispatches an HTTP request to
urlwith retry logic and timeout. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited