NotificationPayload class
Provider-neutral notification model.
Constructors
-
NotificationPayload({required String title, required String message, required ReleaseEvent event, required NotificationSeverity severity, Map<
String, dynamic> metadata = const {}, DateTime? timestamp}) - NotificationPayload.fromReleaseEvent(ReleaseEvent event)
-
factory
Properties
- event → ReleaseEvent
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
-
metadata
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → NotificationSeverity
-
final
- timestamp → DateTime
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited