NotificationResult class
Result object describing the delivery status of a notification provider attempt.
Constructors
- NotificationResult({required String providerName, required bool success, int? statusCode, String? error, int durationMs = 0})
-
const
- NotificationResult.failure(String providerName, String error, {int? statusCode, int durationMs = 0})
-
factory
- NotificationResult.success(String providerName, {int? statusCode, int durationMs = 0})
-
factory
Properties
- durationMs → int
-
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- providerName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int?
-
final
- success → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited