NotificationProvider class abstract
Abstract interface implemented by notification providers (Slack, Discord, Generic Webhook, GitHub).
- Implementers
Constructors
Properties
Methods
-
isConfigured(
Map< String, String> environment) → bool -
Checks if
environmentcontains necessary credentials or configuration for this provider. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
NotificationPayload payload, {required Map< String, String> environment, bool dryRun = false}) → Future<NotificationResult> -
Dispatches
payloadto the destination. Network calls MUST be skipped ifdryRunis true. -
toString(
) → String -
A string representation of this object.
inherited
-
validateConfig(
Map< String, String> environment) → List<String> - Validates configuration and returns any configuration issues or missing variables.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited