ReleaseEvent class
Structured model capturing data associated with a release lifecycle event.
Constructors
-
ReleaseEvent({required ReleaseEventType eventType, required String version, required String buildNumber, required String releaseMode, required List<
String> platforms, String? commit, String? tag, String? releaseNotes, Map<String, String> artifacts = const {}, String deploymentStatus = 'Unknown', String? environment, String? flavor, DateTime? timestamp, String? error, bool isPatch = false})
Properties
-
artifacts
→ Map<
String, String> -
final
- buildNumber → String
-
final
- commit → String?
-
final
- deploymentStatus → String
-
final
- environment → String?
-
final
- error → String?
-
final
- eventType → ReleaseEventType
-
final
- flavor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPatch → bool
-
final
-
platforms
→ List<
String> -
final
- releaseMode → String
-
final
- releaseNotes → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
final
- timestamp → DateTime
-
final
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited