TerminalOutput class
Abstraction for standard CLI output formatting and output streams.
Constructors
- TerminalOutput({StringSink? out, StringSink? err})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- out → StringSink
-
Exposes the stdout string sink.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
detail(
String message) → void - Print detail or indented message.
-
error(
String message) → void - Print error message.
-
info(
String message) → void - Print standard info message.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
success(
String message) → void - Print success message with checkmark or symbol.
-
toString(
) → String -
A string representation of this object.
inherited
-
warning(
String message) → void - Print warning message.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited