PackageManager class
Configuration-driven Package Manager for installing Flutter dependencies.
Constructors
- PackageManager({ProcessRunner runner = const SystemProcessRunner()})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
installAll(
{required String projectPath, required List< DependencyConfig> dependencies, required List<DependencyConfig> devDependencies, String executable = 'flutter'}) → Future<PackageInstallResult> -
Installs
dependenciesanddevDependenciessequentially intoprojectPathusingflutter pub add, then runs a finalflutter pub get. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited