FlutterProjectCreator class
Service responsible for invoking the flutter create command.
Constructors
- FlutterProjectCreator({ProcessRunner runner = const SystemProcessRunner()})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createProject(
{required String projectName, String? workingDirectory, String executable = 'flutter'}) → Future< String> -
Creates a new Flutter baseline project named
projectNameinworkingDirectory. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited