ArtifactIntegrity class
Lightweight artifact integrity verifier calculating and matching SHA-256 checksums.
Constructors
- ArtifactIntegrity()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
computeSha256(
String artifactPath) → Future< String> -
Computes SHA-256 hash string of file at
artifactPath. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verifyArtifact(
{required String artifactPath, String? expectedChecksum}) → Future< bool> -
Verifies artifact existence, readability, non-zero size, and optional
expectedChecksum.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited