ReleaseSummary class
Summary object combining release metadata, commit counts, and patch eligibility information.
Constructors
-
ReleaseSummary({required String version, required String buildNumber, required String releaseMode, required List<
String> platforms, String? branch, String? commitSha, String? tag, String? previousTag, int commitCount = 0, bool hasBreakingChanges = false, Map<String, int> categoryCounts = const {}, Map<String, String> artifacts = const {}, String deploymentStatus = 'Unknown', required String timestamp, Map<String, dynamic> ? shorebirdPatchDetails}) -
const
Properties
-
artifacts
→ Map<
String, String> -
final
- branch → String?
-
final
- buildNumber → String
-
final
-
categoryCounts
→ Map<
String, int> -
final
- commitCount → int
-
final
- commitSha → String?
-
final
- deploymentStatus → String
-
final
- hasBreakingChanges → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
platforms
→ List<
String> -
final
- previousTag → String?
-
final
- releaseMode → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shorebirdPatchDetails
→ Map<
String, dynamic> ? -
final
- tag → String?
-
final
- timestamp → String
-
final
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited