ReleaseRecoveryManager class
Coordinator for release status verification, integrity checking, and recovery operations.
Constructors
- ReleaseRecoveryManager({TerminalOutput? output, ReleaseStateTracker stateTracker = const ReleaseStateTracker(), ReleaseMetadataManager metadataManager = const ReleaseMetadataManager(), ArtifactIntegrity artifactIntegrity = const ArtifactIntegrity(), DeploymentManager? deploymentManager, GitClient gitClient = const GitClient()})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getReleaseStatus(
String projectPath) → Future< String> - Retrieves structured status summary of current or latest release operation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recoverRelease(
String projectPath, {String? stage, bool dryRun = false}) → Future< bool> - Performs deployment-only recovery for a previously failed deployment stage.
-
toString(
) → String -
A string representation of this object.
inherited
-
verifyRelease(
String projectPath) → Future< String> - Verifies artifact and release state integrity without mutating project state.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited