ReleaseResult class
Structured result model communicating the outcome of a release execution.
Constructors
-
ReleaseResult({required bool success, required ReleaseType type, required String message, String? versionName, int? buildNumber, String? targetPlatform, List<
String> executedSteps = const [], List<String> errors = const [], List<String> warnings = const [], Map<String, dynamic> metadata = const {}}) -
const
-
ReleaseResult.failure({required ReleaseType type, required String message, List<
String> errors = const [], List<String> executedSteps = const [], List<String> warnings = const []}) -
Factory helper for creating a failed release result.
factory
-
ReleaseResult.success({required ReleaseType type, required String message, String? versionName, int? buildNumber, String? targetPlatform, List<
String> executedSteps = const [], List<String> warnings = const [], Map<String, dynamic> metadata = const {}}) -
Factory helper for creating a successful release result.
factory
Properties
- buildNumber → int?
-
final
-
errors
→ List<
String> -
final
-
executedSteps
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
-
metadata
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
final
- targetPlatform → String?
-
final
- type → ReleaseType
-
final
- versionName → String?
-
final
-
warnings
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited