ReleaseStateRecord class
Machine-readable state record capturing active or historical release execution details.
Constructors
-
ReleaseStateRecord({required String operation, required String releaseMode, String? environment, String? platform, String? versionName, String? buildNumber, String? commitSha, String? branch, String? tag, required ReleaseStatus status, String? failedStage, String? artifactPath, String? artifactChecksum, List<
String> executedSteps = const [], List<String> errors = const [], List<String> warnings = const [], String? timestamp, int? pid}) -
ReleaseStateRecord.fromJson(Map<
String, dynamic> json) -
factory
Properties
- artifactChecksum → String?
-
final
- artifactPath → String?
-
final
- branch → String?
-
final
- buildNumber → String?
-
final
- commitSha → String?
-
final
- environment → String?
-
final
-
errors
→ List<
String> -
final
-
executedSteps
→ List<
String> -
final
- failedStage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- operation → String
-
final
- pid → int?
-
final
- platform → String?
-
final
- releaseMode → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ReleaseStatus
-
final
- tag → String?
-
final
- timestamp → String
-
final
- versionName → String?
-
final
-
warnings
→ List<
String> -
final
Methods
-
copyWith(
{String? operation, String? releaseMode, String? environment, String? platform, String? versionName, String? buildNumber, String? commitSha, String? branch, String? tag, ReleaseStatus? status, String? failedStage, String? artifactPath, String? artifactChecksum, List< String> ? executedSteps, List<String> ? errors, List<String> ? warnings, String? timestamp, int? pid}) → ReleaseStateRecord -
encodeJson(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited