ReleaseStateTracker class
Persistence manager for tracking current and active release state files.
Constructors
- ReleaseStateTracker()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearCurrentState(
String projectPath, {bool dryRun = false}) → Future< void> - Removes current state file upon complete clean release finalization.
-
getCurrentStateFilePath(
String projectPath) → String - File path of current active release state file.
-
getStateDirectory(
String projectPath) → String -
Directory path where current state files reside relative to
projectPath. -
loadCurrentState(
String projectPath) → Future< ReleaseStateRecord?> -
Loads current active release state for
projectPath, if present. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveState(
String projectPath, ReleaseStateRecord record, {bool dryRun = false}) → Future< String> -
Persists
recordto.flutter_setup/releases/current_state.json. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited