ReleaseValidatorPipeline class
Pre-flight validation pipeline running all registered validators.
Constructors
-
ReleaseValidatorPipeline({List<
ReleaseValidator> validators = const [FlutterProjectValidator(), VersionValidator(), GitValidator(), EnvironmentValidator(), TargetEnvironmentValidator(), ProductionReleaseGuard(), VersionSafetyGuard(), GitTagSafetyGuard()]}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
validators
→ List<
ReleaseValidator> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
ReleaseContext context) → Future< ValidationResult> -
Executes pre-flight validation pipeline for
context.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited