PatchChangeCategory enum
Classification categories for changed files in Git working tree.
Values
- dart → const PatchChangeCategory
- generatedDart → const PatchChangeCategory
- nativeAndroid → const PatchChangeCategory
- nativeIos → const PatchChangeCategory
- dependencies → const PatchChangeCategory
- assets → const PatchChangeCategory
- configuration → const PatchChangeCategory
- unknown → const PatchChangeCategory
Properties
- displayName → String
-
User-friendly display label.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isPatchable → bool
-
Returns true if changes in this category are generally safe for Shorebird OTA patches.
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PatchChangeCategory> - A constant List of the values in this enum, in order of their declaration.