PatchEligibilityResult class
Result model communicating whether project working tree changes are eligible for Shorebird OTA patching.
Constructors
-
PatchEligibilityResult({required bool isEligible, required Map<
PatchChangeCategory, List< categorizedFiles, required String explanation, List<String> >String> blockers = const [], List<String> warnings = const []}) -
const
-
PatchEligibilityResult.evaluate(Map<
PatchChangeCategory, List< categorizedFiles)String> > -
Factory resolving eligibility from a
categorizedFilesmap.factory
Properties
-
blockers
→ List<
String> -
final
-
categorizedFiles
→ Map<
PatchChangeCategory, List< String> > -
final
- explanation → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEligible → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
warnings
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited