ShorebirdClient class
Client wrapping external shorebird CLI operations using ProcessRunner.
Constructors
- ShorebirdClient({ProcessRunner runner = const SystemProcessRunner()})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildPatchArgs(
{required BuildPlatform platform, String? releaseVersion, List< String> extraArgs = const []}) → List<String> -
Builds command argument list for
shorebird patch <platform>. -
buildReleaseArgs(
{required BuildPlatform platform, String? versionName, int? buildNumber, List< String> extraArgs = const []}) → List<String> -
Builds command argument list for
shorebird release <platform>. -
executePatch(
{required String projectPath, required BuildPlatform platform, required bool dryRun, String? releaseVersion, List< String> extraArgs = const []}) → Future<ShorebirdCommandResult> -
Executes
shorebird patch <platform>. -
executeRelease(
{required String projectPath, required BuildPlatform platform, required bool dryRun, String? versionName, int? buildNumber, List< String> extraArgs = const []}) → Future<ShorebirdCommandResult> -
Executes
shorebird release <platform>. -
getShorebirdVersion(
) → Future< String?> - Returns system Shorebird CLI version string, or null if unavailable.
-
isProjectConfigured(
String projectPath) → bool -
Checks if target project directory contains
shorebird.yaml. -
isShorebirdAvailable(
) → Future< bool> -
Checks if
shorebirdbinary is available on system PATH. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited