ShorebirdCommandResult class
Structured result returned by ShorebirdClient command invocations.
Constructors
-
ShorebirdCommandResult({required bool success, required String commandString, int exitCode = 0, String stdout = '', String stderr = '', List<
String> executedSteps = const [], List<String> errors = const []}) -
const
-
ShorebirdCommandResult.failure({required String commandString, int exitCode = 1, String stdout = '', String stderr = '', List<
String> executedSteps = const [], List<String> errors = const []}) -
factory
-
ShorebirdCommandResult.success({required String commandString, String stdout = '', String stderr = '', List<
String> executedSteps = const []}) -
factory
Properties
- commandString → String
-
final
-
errors
→ List<
String> -
final
-
executedSteps
→ List<
String> -
final
- exitCode → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderr → String
-
final
- stdout → String
-
final
- success → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited