TemplateLoader class

Service responsible for loading template files from disk.

Constructors

TemplateLoader()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadFromDirectory(Directory directory) → Template
Loads a template from a directory containing a template.yaml file.
loadFromString(String yamlContent, {String? path}) → Template
Loads a template from a direct YAML string (useful for testing or memory templates).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited