Pure, deterministic service responsible for resolving and deriving variable maps.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resolve(
{required String rawProjectName, String? organization, String? description, String? author}) → Map< String, String> - Resolves raw inputs into a complete token-to-value variable map.
-
resolveComponent(
{required String rawFeatureName, required String componentType, required String rawComponentName}) → Map< String, String> - Resolves component (screen, model, repository) variable variants along with feature name variants.
-
resolveFeature(
{required String rawFeatureName}) → Map< String, String> - Resolves feature name variants.