BuildNumberStrategy class
Strategy abstraction for determining target build numbers for release builds.
Constructors
-
BuildNumberStrategy({GitClient gitClient = const GitClient(), Map<
String, String> ? environment}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveBuildNumber(
{required String projectPath, required ProjectVersion currentVersion, int? explicitBuildNumber}) → Future< int> -
Resolves the next build number for
currentVersionbased on strategy rules. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited